@@ -16,11 +16,11 @@
 
 # Author: Cyril Jaquier
 # 
-# $Revision: 454 $
+# $Revision: 553 $
 
 __author__ = "Cyril Jaquier"
-__version__ = "$Revision: 454 $"
-__date__ = "$Date: 2006-11-12 11:54:19 +0100 (Sun, 12 Nov 2006) $"
+__version__ = "$Revision: 553 $"
+__date__ = "$Date: 2007-02-26 00:53:22 +0100 (Mon, 26 Feb 2007) $"
 __copyright__ = "Copyright (c) 2004 Cyril Jaquier"
 __license__ = "GPL"
 
@@ -62,9 +62,11 @@ class BanManager:
 	# @param value the time
 	
 	def setBanTime(self, value):
-		self.__lock.acquire()
-		self.__banTime = int(value)
-		self.__lock.release()
+		try:
+			self.__lock.acquire()
+			self.__banTime = int(value)
+		finally:
+			self.__lock.release()
 	
 	##
 	# Get the ban time.
@@ -85,9 +87,11 @@ class BanManager:
 	# @param value total number
 	
 	def setBanTotal(self, value):
-		self.__lock.acquire()
-		self.__banTotal = value
-		self.__lock.release()
+		try:
+			self.__lock.acquire()
+			self.__banTotal = value
+		finally:
+			self.__lock.release()
 	
 	##
 	# Get the total number of banned address.
@@ -100,7 +104,19 @@ class BanManager:
 			return self.__banTotal
 		finally:
 			self.__lock.release()
+
+	##
+	# Returns a copy of the IP list.
+	#
+	# @return IP list
 	
+	def getBanList(self):
+		try:
+			self.__lock.acquire()
+			return [m.getIP() for m in self.__banList]
+		finally:
+			self.__lock.release()
+
 	##
 	# Create a ban ticket.
 	#
