@@ -16,24 +16,45 @@
 
 # Author: Cyril Jaquier
 # 
-# $Revision: 504 $
+# $Revision: 556 $
 
 __author__ = "Cyril Jaquier"
-__version__ = "$Revision: 504 $"
-__date__ = "$Date: 2006-12-23 17:37:17 +0100 (Sat, 23 Dec 2006) $"
+__version__ = "$Revision: 556 $"
+__date__ = "$Date: 2007-03-07 21:54:32 +0100 (Wed, 07 Mar 2007) $"
 __copyright__ = "Copyright (c) 2004 Cyril Jaquier"
 __license__ = "GPL"
 
 import time
 
+##
+# MyTime class.
+#
+# This class is a wrapper around time.time()  and time.gmtime(). When
+# performing unit test, it is very useful to get a fixed value from these
+# functions.
+# Thus, time.time() and time.gmtime() should never be called directly.
+# This wrapper should be called instead. The API are equivalent.
+
 class MyTime:
 	
 	myTime = None
 	
+	##
+	# Sets the current time.
+	#
+	# Use None in order to always get the real current time.
+	#
+	# @param t the time to set or None
+	
 	@staticmethod
 	def setTime(t):
 		MyTime.myTime = t
 	
+	##
+	# Equivalent to time.time()
+	#
+	# @return time.time() if setTime was called with None
+	
 	@staticmethod
 	def time():
 		if MyTime.myTime == None:
@@ -41,6 +62,11 @@ class MyTime:
 		else:
 			return MyTime.myTime
 	
+	##
+	# Equivalent to time.gmtime()
+	#
+	# @return time.gmtime() if setTime was called with None
+	
 	@staticmethod
 	def gmtime():
 		if MyTime.myTime == None:
